pub fn get_runtime_table(image_ptr: *mut c_void) -> (*mut RuntimeFunction, u32)Available on Windows only.
Returns a pair containing a pointer to the Exception data of an arbitrary module and the size of the
corresponding PE section (.pdata). In case that it fails to retrieve this information, it returns
null values.