pub fn map_module_to_memory(
module_ptr: *const u8,
image_ptr: *mut c_void,
pe_info: &PeMetadata,
) -> Result<(), String>Available on Windows only.
Maps a module to a valid memory space in the current process.
The parameters required are a vector with the module content, the base address where the module should be mapped and the module’s metadata.